==> pawm-2.2.4.tar.bz2: pawm-2.2.4/src/x.h <==
/*
    Filename: x.h
    Synopsis: X framework headers.
    
                        Copyright (C) 2000, 2001 
           Ral Nez de Arenas Coronado <raul@pleyades.net>
	        David Gmez Espinosa <david@pleyades.net>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to:

        Free Software Foundation, Inc.
        59 Temple Place, Suite 330
        Boston, MA 02111-1307 USA

*/
#ifndef __X__STUFF__H__
#define __X__STUFF__H__

#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/Xatom.h>
#include <X11/Xproto.h>
#include <X11/cursorfont.h>
#include <X11/xpm.h>
#include <X11/keysym.h>
#include <X11/extensions/shape.h>
#include <X11/extensions/Xrender.h>
#include <sys/wait.h>
#include <sys/file.h>
#include <sys/stat.h>
#include <stdlib.h>
#include <stdbool.h>
#include "mobs.h"
#include "chain.h"
#include "cfgpool.h"
#ifdef ENABLE_STARTUP
#include <libsn/sn.h>
#endif


typedef void (*callback) (void *);

/* Global variables for all files which includes x.h */
extern Display *display;
#ifdef ENABLE_STARTUP
extern SnDisplay *sn_display;
extern volatile bool startup_timeout;
#endif
extern char *display_name;
extern Cursor x_root_cursor;
extern CfgPool pawmpool;
extern struct _atoms atoms;

struct _atoms {
	Atom string;
	Atom utf8_string;
	/* ICCCM atoms*/
	Atom wm_name;
	Atom wm_icon_name;
	Atom wm_normal_hints;
	Atom wm_transient_for;
	Atom wm_state;
	Atom wm_delete_window;
	Atom wm_protocols;
	Atom wm_change_state;
	/* EWMH atoms*/
	Atom net_wm_name;
	Atom net_wm_icon_name;
	Atom net_wm_window_type;
	Atom net_wm_window_type_desktop;
	Atom net_wm_window_type_dock;
	Atom net_wm_window_type_toolbar;
	Atom net_wm_window_type_menu;
	Atom net_wm_window_type_utility;
	Atom net_wm_window_type_splash;
	Atom net_wm_window_type_dialog;
	Atom net_wm_window_type_normal;
	Atom net_wm_state;
	Atom net_wm_state_modal;
	Atom net_wm_state_sticky;
	Atom net_wm_state_maximized;
	Atom net_wm_state_shaded;
	Atom net_wm_state_skip_taskbar;
	Atom net_wm_state_skip_pager;
	Atom net_wm_state_hidden;
	Atom net_wm_state_fullscreen;
	Atom net_wm_state_above;
	Atom net_wm_state_below;
	Atom net_supported;
	Atom net_current_desktop;
	Atom net_active_window;
	Atom net_workarea;
	Atom net_supporting_wm_check;
	Atom net_number_of_desktops;
	Atom net_client_list;
	Atom net_wm_icon;
	Atom net_wm_ping;
	Atom net_wm_strut_partial;
	/* Other atoms */
	Atom root_pixmap;
	Atom motif_wm_hints;
} atoms;

/*
    NOTE: using these macros before calling x_init() will result
in undefined behaviour. Well, not undefined, but *BAD* behaviour.
*/

/* Basic definitions */
#define ROOT         (DefaultRootWindow(display))
#define SCREENI      (DefaultScreen(display))
#define SCREEN       (DefaultScreenOfDisplay(display))
#define VISUAL       (DefaultVisualOfScreen(SCREEN))
#define DEPTH        (DefaultDepth(display, SCREENI))
#define COLORMAP     (DefaultColormap(display, SCREENI))
#define BLACK        (BlackPixel(display, SCREENI))
#define WHITE        (WhitePixel(display, SCREENI))
#define CURSOR       (x_root_cursor)
#define DWIDTH       ((unsigned int)DisplayWidth(display, SCREENI))
#define DHEIGHT      ((unsigned int)DisplayHeight(display, SCREENI))
#define RENDERFORMAT (XRenderFindVisualFormat(display, VISUAL))

#define GOT(event,who) SAY("Got "#event" on "#who)

#define NOTFOUNDMSG "Failure retrieving %s from config file"

/* Type of the event handlers */
typedef void (*Handler) (XEvent *, void *);

typedef struct sxImage {
	Pixmap pixmap;
	Pixmap mask;
	int w;
	int h;
} *xImage;

void 		x_init (void);
void 		x_done (void);
void 		x_main_loop(void);
void 		x_dispatch (XEvent *);
void 		x_addsloot (Window, Handler, void *);
void 		x_delsloot (Window, Handler, void *);
xImage 		x_build_pixmap (char *);
xImage 		x_build_pixmap_from_argb (void *, size_t);
void 		x_destroy_pixmap(xImage);
unsigned long 	x_pixel (const char *);
unsigned long 	x_color (const char *);
char 	       *x_colorstr (const char *);
unsigned char  *x_get_property(Window , Atom, Atom , unsigned long *);
void 		x_set_property(Window , Atom, Atom , unsigned char *, int);
void		x_set_property_utf8(Window , Atom , unsigned char *);

#endif

==> pawm-2.2.7.tar.bz2: pawm-2.2.7/src/x.h <==
/*
    Filename: x.h
    Synopsis: X framework headers.
    
                        Copyright (C) 2000, 2001 
           Ral Nez de Arenas Coronado <raul@pleyades.net>
	        David Gmez Espinosa <david@pleyades.net>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to:

        Free Software Foundation, Inc.
        59 Temple Place, Suite 330
        Boston, MA 02111-1307 USA

*/
#ifndef __X__STUFF__H__
#define __X__STUFF__H__

#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/Xatom.h>
#include <X11/Xproto.h>
#include <X11/cursorfont.h>
#include <X11/xpm.h>
#include <X11/keysym.h>
#include <X11/extensions/shape.h>
#include <X11/extensions/Xrender.h>
#include <sys/wait.h>
#include <sys/file.h>
#include <sys/stat.h>
#include <stdlib.h>
#include <stdbool.h>
#include "mobs.h"
#include "chain.h"
#include "cfgpool.h"
#ifdef ENABLE_STARTUP
#include <libsn/sn.h>
#endif


typedef void (*callback) (void *);

/* Global variables for all files which includes x.h */
extern Display *display;
#ifdef ENABLE_STARTUP
extern SnDisplay *sn_display;
extern volatile bool startup_timeout;
#endif
extern char *display_name;
extern Cursor x_root_cursor;
extern struct _visuals visuals;
extern CfgPool pawmpool;
extern struct _atoms atoms;
extern GC xgc;
extern GC alpha_xgc; /* Graphic context for ARGB visuals */

struct _visuals {
	Visual *visual;
	Visual *argb_visual;
	Colormap argb_colormap;
} visuals;

struct _atoms {
	Atom string;
	Atom utf8_string;
	/* ICCCM atoms*/
	Atom wm_name;
	Atom wm_icon_name;
	Atom wm_normal_hints;
	Atom wm_transient_for;
	Atom wm_state;
	Atom wm_delete_window;
	Atom wm_protocols;
	Atom wm_change_state;
	/* EWMH atoms*/
	Atom net_wm_name;
	Atom net_wm_icon_name;
	Atom net_wm_window_type;
	Atom net_wm_window_type_desktop;
	Atom net_wm_window_type_dock;
	Atom net_wm_window_type_toolbar;
	Atom net_wm_window_type_menu;
	Atom net_wm_window_type_utility;
	Atom net_wm_window_type_splash;
	Atom net_wm_window_type_dialog;
	Atom net_wm_window_type_normal;
	Atom net_wm_state;
	Atom net_wm_state_modal;
	Atom net_wm_state_sticky;
	Atom net_wm_state_maximized;
	Atom net_wm_state_shaded;
	Atom net_wm_state_skip_taskbar;
	Atom net_wm_state_skip_pager;
	Atom net_wm_state_hidden;
	Atom net_wm_state_fullscreen;
	Atom net_wm_state_above;
	Atom net_wm_state_below;
	Atom net_supported;
	Atom net_current_desktop;
	Atom net_active_window;
	Atom net_workarea;
	Atom net_supporting_wm_check;
	Atom net_number_of_desktops;
	Atom net_client_list;
	Atom net_wm_icon;
	Atom net_wm_ping;
	Atom net_wm_strut_partial;
	/* Other atoms */
	Atom root_pixmap;
	Atom motif_wm_hints;
} atoms;

/* MOTIF WM hints. Define only flags used by pawm */
#define MWM_HINTS_DECORATIONS           (1L<<1)
#define MWM_DECOR_ALL                   (1L<<0)
#define MWM_DECOR_BORDER      	        (1L<<1)


/* NOTE: using these macros before calling x_init() will result
 * in undefined behaviour. Well, not undefined, but *BAD* behaviour.  */

/* Basic definitions */
#define ROOT         (DefaultRootWindow(display))
#define SCREENI      (DefaultScreen(display))
#define SCREEN       (DefaultScreenOfDisplay(display))
#define DEFAULTVISUAL       (DefaultVisualOfScreen(SCREEN))
#define DEPTH        (DefaultDepth(display, SCREENI))
//#define DEFAULTVISUAL       (visuals.argb_visual)
//#define DEPTH        (32)
#define COLORMAP     (DefaultColormap(display, SCREENI))
#define BLACK        (BlackPixel(display, SCREENI))
#define WHITE        (WhitePixel(display, SCREENI))
#define CURSOR       (x_root_cursor)
#define DWIDTH       ((unsigned int)DisplayWidth(display, SCREENI))
#define DHEIGHT      ((unsigned int)DisplayHeight(display, SCREENI))
#define RENDERFORMAT (XRenderFindVisualFormat(display, DEFAULTVISUAL))

#define GOT(event,who) SAY("Got "#event" on "#who)

#define NOTFOUNDMSG "Failure retrieving %s from config file"

/* Type of the event handlers */
typedef void (*Handler) (XEvent *, void *);

typedef struct sxImage {
	Pixmap pixmap;
	Pixmap mask;
	int w;
	int h;
} *xImage;

void 		x_init (void);
void 		x_done (void);
void 		x_main_loop(void);
void 		x_dispatch (XEvent *);
void 		x_addsloot (Window, Handler, void *);
void 		x_delsloot (Window, Handler, void *);
xImage 		x_build_pixmap (char *);
xImage 		x_build_pixmap_from_argb (void *, size_t);
void 		x_destroy_pixmap(xImage);
unsigned long 	x_pixel (const char *);
unsigned long 	x_color (const char *);
char 	       *x_colorstr (const char *);
unsigned char  *x_get_property(Window , Atom, Atom , unsigned long *);
void 		x_set_property(Window , Atom, Atom , unsigned char *, int);
void		x_set_property_utf8(Window , Atom , unsigned char *);
void		x_alpha_gc_init(Window);

#endif
